<?php
// Error reporting for development (set to 0 for production)
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Set the default timezone
date_default_timezone_set("Asia/Calcutta");

// Get the current date and time
$fromdate = date('Y-m-d H:i:s');

// Include the database configuration file
include('inc/config.php');
header('Content-Type: application/json');

// Check if the request method is POST
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $action = $_POST['action'] ?? null;

    // Validate the action parameter
    if (!$action) {
        echo json_encode(['status' => 'Error', 'message' => 'Invalid action']);
        exit;
    }

    // Handle Create and Update actions
    if (in_array($action, ['Create', 'Update'], true)) {
        // Sanitize and validate input data
        $uniqueID = $_POST['UniqueID'] ?? mt_rand(100000, 999999);
        $name = trim($_POST['Name'] ?? '');
        $email = filter_var($_POST['Email'] ?? '', FILTER_SANITIZE_EMAIL);
        $phone = preg_replace('/[^0-9]/', '', $_POST['Phone'] ?? '');
        $password = $_POST['Password'] ?? '';
        $degree = trim($_POST['Degree'] ?? '');
        $address = trim($_POST['Address'] ?? '');
        $extraField1 = trim($_POST['ExtraField1'] ?? '');
        $clinicName = trim($_POST['ClinicName'] ?? '');
        $id = $_POST['id'] ?? null;

        // Validate required fields
        if (empty($name) || !filter_var($email, FILTER_VALIDATE_EMAIL) || empty($phone) || empty($password)) {
            echo json_encode(['status' => 'Error', 'message' => 'Required fields are missing or invalid']);
            exit;
        }

        // Hash the password for security (only when creating or updating)
        //$hashedPassword = password_hash($password, PASSWORD_BCRYPT);

        // Handle file upload for ProfilePhoto
        $profilePhoto = null;
        if (isset($_FILES['ProfilePhoto']) && $_FILES['ProfilePhoto']['error'] === UPLOAD_ERR_OK) {
            $allowedTypes = ['image/jpeg', 'image/png', 'image/gif'];
            if (in_array($_FILES['ProfilePhoto']['type'], $allowedTypes) && $_FILES['ProfilePhoto']['size'] < 2 * 1024 * 1024) {
                $uploadDir = 'uploads/';
                $fileName = uniqid() . '_' . basename($_FILES['ProfilePhoto']['name']);
                $filePath = $uploadDir . $fileName;

                if (move_uploaded_file($_FILES['ProfilePhoto']['tmp_name'], $filePath)) {
                    $profilePhoto = $fileName;
                } else {
                    echo json_encode(['status' => 'Error', 'message' => 'File upload failed']);
                    exit;
                }
            } else {
                echo json_encode(['status' => 'Error', 'message' => 'Invalid file type or size']);
                exit;
            }
        }

        if ($action === 'Create') {
            // Check for duplicate email or phone
            $stmt = $conn->prepare("SELECT * FROM Doctors WHERE Email = ? OR Phone = ?");
            $stmt->bind_param("ss", $email, $phone);
            $stmt->execute();
            $result = $stmt->get_result();

            if ($result->num_rows > 0) {
                echo json_encode(['status' => 'Error', 'message' => 'Email or Phone already exists']);
                exit;
            }

            // Insert new doctor
            $stmt = $conn->prepare(
                "INSERT INTO Doctors (UniqueID, Name, Email, Phone, Password, Degree, ProfilePhoto, Address, RegisterDate, ExtraField1, ClinicName, Role, status)
                 VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, 'Doctor', '1')"
            );
            $stmt->bind_param("sssssssssss", $uniqueID, $name, $email, $phone, $password, $degree, $profilePhoto, $address, $fromdate, $extraField1, $clinicName);
            if ($stmt->execute()) {
                echo json_encode(['status' => 'Create']);
            } else {
                echo json_encode(['status' => 'Error', 'message' => $stmt->error]);
            }
        } elseif ($action === 'Update' && $id) {
    // Check for duplicate email or phone excluding the current doctor
    $stmt = $conn->prepare("SELECT * FROM Doctors WHERE (Email = ? OR Phone = ?) AND DoctorID != ?");
    $stmt->bind_param("ssi", $email, $phone, $id);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows > 0) {
        echo json_encode(['status' => 'Error', 'message' => 'Email or Phone already exists']);
        exit;
    }

    // Fetch current profile photo if a new one is uploaded
    $oldPhoto = null;
    if ($profilePhoto) {
        $stmt = $conn->prepare("SELECT ProfilePhoto FROM Doctors WHERE DoctorID = ?");
        $stmt->bind_param("i", $id);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($result->num_rows > 0) {
            $row = $result->fetch_assoc();
            $oldPhoto = $row['ProfilePhoto'];
        }
    }

    // Update doctor details
    $query = "UPDATE Doctors SET Name = ?, Email = ?, Phone = ?, Password = ?, Degree = ?, Address = ?, ExtraField1 = ?, ClinicName = ?, Updatedat = ?";
    $params = [$name, $email, $phone, $password, $degree, $address, $extraField1, $clinicName, $fromdate];
    $types = "sssssssss";

    if ($profilePhoto) {
        $query .= ", ProfilePhoto = ?";
        $params[] = $profilePhoto;
        $types .= "s";
    }
    $query .= " WHERE DoctorID = ?";
    $params[] = $id;
    $types .= "i";

    $stmt = $conn->prepare($query);
    $stmt->bind_param($types, ...$params);

    if ($stmt->execute()) {
        // Delete old profile photo if a new one was uploaded and the update was successful
        if ($profilePhoto && $oldPhoto) {
            $oldPhotoPath = 'uploads/' . $oldPhoto;
            if (file_exists($oldPhotoPath)) {
                unlink($oldPhotoPath); // Delete the old photo
            }
        }
        echo json_encode(['status' => 'Update']);
    } else {
        echo json_encode(['status' => 'Error', 'message' => $stmt->error]);
    }
}

    }

    // Select doctor by ID
    elseif ($action === 'Select' && isset($_POST['id'])) {
        $id = (int) $_POST['id'];
        $stmt = $conn->prepare("SELECT * FROM Doctors WHERE DoctorID = ?");
        $stmt->bind_param("i", $id);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($result->num_rows > 0) {
            $row = $result->fetch_assoc();
            $row['ProfilePhoto'] = $row['ProfilePhoto'] ? 'uploads/' . $row['ProfilePhoto'] : null;
            echo json_encode($row);
        } else {
            echo json_encode(['status' => 'Error', 'message' => 'Record not found']);
        }
    }

    // Delete doctor by ID
    elseif ($action === 'Delete' && isset($_POST['id'])) {
        $id = (int) $_POST['id'];
        $stmt = $conn->prepare("SELECT ProfilePhoto FROM Doctors WHERE DoctorID = ?");
        $stmt->bind_param("i", $id);
        $stmt->execute();
        $result = $stmt->get_result();

        if ($result->num_rows > 0) {
            $row = $result->fetch_assoc();

            if (!empty($row['ProfilePhoto'])) {
                $filePath = 'uploads/' . $row['ProfilePhoto'];
                if (file_exists($filePath)) {
                    unlink($filePath);
                }
            }

            $stmt = $conn->prepare("DELETE FROM Doctors WHERE DoctorID = ?");
            $stmt->bind_param("i", $id);
            if ($stmt->execute()) {
                echo json_encode(['status' => 'Delete', 'message' => 'Record deleted successfully']);
            } else {
                echo json_encode(['status' => 'Error', 'message' => $stmt->error]);
            }
        } else {
            echo json_encode(['status' => 'Error', 'message' => 'Record not found']);
        }
    }

    // Change status of a doctor
    elseif ($action === 'StatusChange' && isset($_POST['id'])) {
    $id = (int)$_POST['id'];
    $stmt = $conn->prepare("SELECT status FROM Doctors WHERE DoctorID = ?");
    $stmt->bind_param("i", $id);
    $stmt->execute();
    $result = $stmt->get_result();

    if ($result->num_rows > 0) {
        $row = $result->fetch_assoc();
        $newStatus = $row['status'] == 1 ? 0 : 1; // Toggle status

        error_log("New Status: $newStatus, DoctorID: $id"); // Debugging log
        
        $stmt = $conn->prepare("UPDATE Doctors SET status = ? WHERE DoctorID = ?");
        $stmt->bind_param("ii", $newStatus, $id);
        
        if ($stmt->execute()) {
            echo json_encode(['status' => 'Status Updated', 'newStatus' => $newStatus]);
        } else {
            echo json_encode(['status' => 'Error', 'message' => $stmt->error]);
        }
    } else {
        echo json_encode(['status' => 'Error', 'message' => 'Record not found']);
    }
}


}

// Close the database connection
mysqli_close($conn);
?>
